@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-03-15'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,12 +10,12 @@ use warnings;
 use Moose;
 use namespace::autoclean;
 
-use Bencher;
+use Bencher::Backend;
 use File::Spec::Functions qw(catfile);
 use Module::Load;
 
 # we need the version to insert to generated test scripts, prereqs.
-$Bencher::VERSION or die "Please use Bencher with a version number";
+$Bencher::Backend::VERSION or die "Please use Bencher with a version number";
 
 with (
     'Dist::Zilla::Role::BeforeBuild',
@@ -114,11 +114,11 @@ sub gather_files {
 
 use Test::More;
 
-eval "use Bencher ].$Bencher::VERSION.q[";
-plan skip_all => "Bencher ].$Bencher::VERSION.q[ required to run benchmark" if $@;
+eval "use Bencher::Backend ].$Bencher::VERSION.q[";
+plan skip_all => "Bencher::Backend ].$Bencher::VERSION.q[ required to run benchmark" if $@;
 plan skip_all => "EXTENDED_TESTING not turned on" unless $ENV{EXTENDED_TESTING};
 
-diag explain Bencher::bencher(action=>'bench', scenario_module=>'].$bs_name.q[');
+diag explain Bencher::Backend::bencher(action=>'bench', return_meta=>1, scenario_module=>'].$bs_name.q[');
 ok 1;
 
 done_testing();
@@ -132,7 +132,7 @@ done_testing();
           );
     }
     $self->zilla->register_prereqs(
-        {phase=>'test', type=>'requires'}, 'Bencher', $Bencher::VERSION);
+        {phase=>'test', type=>'requires'}, 'Bencher::Backend', $Bencher::Backend::VERSION);
 }
 
 sub munge_files {
@@ -148,8 +148,8 @@ sub munge_files {
         # add prereq to participant modules
         my $pkg = $1; $pkg =~ s!/!::!g;
         load $pkg;
-        my $scenario = Bencher::parse_scenario(scenario=>${"$pkg\::scenario"});
-        my @modules = Bencher::_get_participant_modules($scenario);
+        my $scenario = Bencher::Backend::parse_scenario(scenario=>${"$pkg\::scenario"});
+        my @modules = Bencher::Backend::_get_participant_modules($scenario);
         for my $mod (@modules) {
             next if $seen_mods{$mod}++;
             my $ver = $scenario->{modules}{$mod}{version} // 0;
@@ -181,8 +181,6 @@ __PACKAGE__->meta->make_immutable;
 1;
 # ABSTRACT: Plugin to use when building Bencher::Scenario::* distribution
 
-
-
 __END__
 
 =pod
@@ -195,7 +193,7 @@ Dist::Zilla::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.10 of Dist::Zilla::Plugin::Bencher::Scenario (from Perl distribution Dist-Zilla-Plugin-Bencher-Scenario), released on 2016-01-13.
+This document describes version 0.11 of Dist::Zilla::Plugin::Bencher::Scenario (from Perl distribution Dist-Zilla-Plugin-Bencher-Scenario), released on 2016-03-15.
 
 =head1 SYNOPSIS
 
@@ -212,7 +210,7 @@ It currently dos the following:
 
 =item * Add the benchmarked modules as RuntimeRequires prereqs
 
-=item * Add Bencher (the currently installed version during building) to TestRequires prereq and add test files C<t/bench.t-*>
+=item * Add Bencher::Backend (the currently installed version during building) to TestRequires prereq and add test files C<t/bench.t-*>
 
 =item * Fill-in ABSTRACT from scenario's summary
 
@@ -220,12 +218,6 @@ It currently dos the following:
 
 =for Pod::Coverage .+
 
-=head1 SEE ALSO
-
-L<Bencher>
-
-L<Pod::Weaver::Plugin::Bencher::Scenario>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-Bencher-Scenario>.
@@ -242,6 +234,12 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Bencher>
+
+L<Pod::Weaver::Plugin::Bencher::Scenario>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
@@ -254,4 +252,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
